OSSP CVS Repository

ossp - Difference in ossp-pkg/rc/rc.h versions 1.32 and 1.33
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/rc/rc.h 1.32 -> 1.33

--- rc.h 2002/06/28 14:20:23     1.32
+++ rc.h 2002/06/28 17:43:23     1.33
@@ -59,10 +59,13 @@
     RC_ERR_SYS = 5,  /* System error (see errno) */
     RC_ERR_IO  = 6,  /* Input/output error       */
     RC_ERR_INT = 7,  /* Internal error           */
-    RC_WRN_0   = 8,  /* Warning base             */
-    RC_WRN_OWR = 9,  /* Overwrite warning        */
-    RC_WRN_NUL = 10, /* NULL pointer warning     */
-    RC_WRN_TRM = 11  /* Request to terminate app */
+    RC_ERR_FNC = 8,  /* Func file not found      */
+    RC_ERR_DIR = 9,  /* Location dir not found   */
+    RC_ERR_RCF = 10, /* Rc file not found        */
+    RC_WRN_0   = 11, /* Warning base             */
+    RC_WRN_OWR = 12, /* Overwrite warning        */
+    RC_WRN_NUL = 13, /* NULL pointer warning     */
+    RC_WRN_TRM = 14  /* Request to terminate app */
 } rc_return_t;
 
 /* Config function prototypes */
@@ -109,7 +112,7 @@
 /* Script function prototypes */
 rc_script_t *scriptNew(void);
 rc_return_t scriptAppend(rc_script_t *, char *, size_t);
-const char *scriptSection(rc_script_t *, const char *);
+char *scriptSection(rc_script_t *, const char *);
 rc_return_t scriptDump(rc_script_t *);
 rc_return_t scriptDelete(rc_script_t *);
 

CVSTrac 2.0.1